=======
Credits
=======

Development Lead
----------------

* Daniel Scheffler <danschef@gfz-potsdam.de>
** <http://www.gfz-potsdam.de/en/section/remote-sensing/staff/profil/daniel-scheffler/>


Contributors
------------

* Jessica Palka <jessica.palka@gfz-potsdam.de>

